##############################################################################
#
# Copyright (c) 2001, 2002 Zope Corporation and Contributors.
# All Rights Reserved.
# 
# This software is subject to the provisions of the Zope Public License,
# Version 2.0 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
# 
##############################################################################
"""This module tests the regular persistent Translation Service.

$Id: testSimpleTranslationService.py,v 1.2 2002/08/23 21:01:18 lalo Exp $
"""
import unittest
from AltPTi18n.SimpleTranslationService import SimpleTranslationService

class Environment:

    def __init__(self, langs=()):
        self.langs = langs

    def getPreferredLanguages(self):
        return self.langs


class TestSimpleTranslationService(unittest.TestCase):

    def _getTranslationService(self):
        service = SimpleTranslationService(
            {('default', 'en', 'short_greeting'): 'Hello!',
             ('default', 'pt_BR', 'short_greeting'): u'Ol!',
             ('default', 'en', 'greeting'): 'Hello $name, how are you?',
             ('default', 'pt_BR', 'greeting'): u'Ol $name, como vai voc?'}
            ) 
        return service

    def setUp(self):
        self._service = self._getTranslationService() 

    # I know, I know. This is not part of the interface, but it is implemented
    # in every Translation Service, so it fits well here.
    def testInterpolation(self):
        service = self._service
        interp = service.interpolate
        eq = self.assertEqual
        mapping = {'name': 'Zope', 'version': '3x'}
        # Test simple interpolations
        eq(interp('This is $name.', mapping), 'This is Zope.')
        eq(interp('This is ${name}.', mapping), 'This is Zope.')
        # Test more than one interpolation variable
        eq(interp('This is $name version $version.', mapping),
           'This is Zope version 3x.')
        eq(interp('This is ${name} version $version.', mapping),
           'This is Zope version 3x.')
        eq(interp('This is $name version ${version}.', mapping),
           'This is Zope version 3x.')
        eq(interp('This is ${name} version ${version}.', mapping),
           'This is Zope version 3x.')
        # Test escaping the $
        eq(interp('This is $$name.', mapping), 'This is $$name.')
        eq(interp('This is $${name}.', mapping), 'This is $${name}.')
        
    def testSimpleTranslate(self):
        translate = self._service.translate
        eq = self.assertEqual
        # Test that a given message id is properly translated in a supported
        # language
        eq(translate('default', 'short_greeting', target_language='pt_BR'),
           u'Ol!')
        # Same test, but use the context argument
        context = Environment(('pt_BR', 'en'))
        eq(translate('default', 'short_greeting', context=context),
           u'Ol!')
    
    def testDynamicTranslate(self):
        translate = self._service.translate
        eq = self.assertEqual
        # Testing both translation and interpolation
        eq(translate('default', 'greeting', mapping={'name': 'Sidnei'},
                     target_language='pt_BR'),
           u'Ol Sidnei, como vai voc?')

    def testGetDomain(self):
        service = self._service    
        domain = service.getDomain('default')

    def testDomainTranslate(self):
        service = self._service    
        domain = service.getDomain('default')
        translate = domain.translate
        eq = self.assertEqual
        # target language argument
        eq(translate('short_greeting', target_language='pt_BR'), u'Ol!')
        # context argument
        context = Environment(('pt_BR', 'en'))
        eq(translate('short_greeting', context=context), u'Ol!')


def test_suite():
    loader = unittest.TestLoader()
    return loader.loadTestsFromTestCase(TestSimpleTranslationService)

if __name__ == '__main__':
    unittest.TextTestRunner().run(test_suite())
